@@ -2,7 +2,7 @@ package Catmandu::Fix::pica_add;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.15';
+our $VERSION = '1.16';
 
 use Moo;
 use Catmandu::Util::Path qw(as_path);
@@ -138,7 +138,8 @@ If PICA field does not exist, it will be created.
 
 =head1 SEE ALSO
 
-See L<Catmandu::Fix::pica_set> for setting a new value to an existing subfield.
+See L<Catmandu::Fix::pica_set> and L<Catmandu::Fix:pica_update> for setting
+new values to (sub)fields.
 
 See L<Catmandu::Fix::pica_map> if you want to copy values from a PICA record.
 
